import { FormSchema } from '@/components/Form';
import { useUserStore } from '@/store/modules/user';
import { BasicColumn } from '@/components/Table';

const deptId = useUserStore().userInfo.deptParentId;
export const searchForm: FormSchema[] = [
  {
    field: 'filingCycle',
    label: '',
    defaultValue: new Date(),
    component: 'DatePicker',
    componentProps: {
      placeholder: '选择填报周期',
      style: { width: '100%' },
      picker: 'year',
      valueFormat: 'YYYY',
      format: 'YYYY',
    },
    colProps: { span: 4 },
  },
  {
    field: 'planType',
    label: '',
    defaultValue: '自投',
    component: 'Select',
    componentProps: {
      options: [
        { label: '自投', value: '自投' },
        { label: '代建', value: '代建' },
        { label: '承建', value: '承建' },
        { label: '储备', value: '储备' },
      ],
      placeholder: '类型',
    },
    colProps: { span: 4 },
  },
  {
    field: 'company',
    label: '',
    show: deptId == '100',
    component: 'Select',
    componentProps: {
      options: [],
      placeholder: '公司名称',
    },
    colProps: { span: 4 },
  },
];
export function getBasicColumns(year: string, planType: string): BasicColumn[] {
  return [
    {
      title: year + '年' + planType + '工程项目投资计划',
      colSpan: 6,
      children: [
        {
          title: '公司名称',
          dataIndex: 'company',
          fixed: 'left',
          width: 250,
          customCell: (_, any) => ({
            rowSpan: _.companyrowSpan,
          }),
        },
        {
          title: '项目类型',
          dataIndex: 'projectType',
          fixed: 'left',
          width: 300,
          slots: { customRender: 'projectType' },
        },
        {
          title: '项目个数',
          dataIndex: 'proNum',
          width: 200,
        },
        {
          title: '合同总额',
          dataIndex: 'contractAmount',

          className: planType === '承建' ? 'tableShow' : 'tableHiddle',
        },
        {
          title: '投资总额(万元)',
          dataIndex: 'totalInvestment',

          className: planType != '承建' ? 'tableShow' : 'tableHiddle',
        },
        {
          title: year + '年计划完成产值',
          dataIndex: 'planCompleteOutputValue',

          className: planType === '承建' ? 'tableShow' : 'tableHiddle',
        },
        {
          title: year + '年计划完成投资额度',
          dataIndex: 'planOutputValue',
          className: planType != '承建' ? 'tableShow' : 'tableHiddle',
        },
        {
          title: year + '年计划资金',
          dataIndex: 'planFunds',
          className: planType != '储备' ? 'tableShow' : 'tableHiddle',
        },
      ],
    },
  ];
}
export function getDtailsBasicColumns(year: string, planType: string): BasicColumn[] {
  const column: BasicColumn[] = [
    {
      title: '序号',
      dataIndex: 'index',
      fixed: 'left',
      width: 180,
      ifShow: true,
      slots: { customRender: 'index' },
    },
    {
      title: '项目名称',
      dataIndex: 'projectName',
      fixed: 'left',
      width: 180,
      ifShow: true,
    },
    {
      title: '建设地点',
      dataIndex: 'constructionSite',
      width: 180,
      ifShow: true,
    },
    {
      title: '项目概况',
      dataIndex: 'projectOverview',
      width: 200,
      ifShow: true,
    },
    {
      title: '建设规模',
      dataIndex: 'constructionScale',
      width: 150,
      ifShow: true,
    },
    {
      title: '建设目的及功能',
      dataIndex: 'constructionPurpose',
      width: 150,
      ifShow: true,
    },
    {
      title: '建设模式',
      dataIndex: 'constructionMode',
      width: 150,
      ifShow: true,
    },
    {
      title: '资金来源',
      dataIndex: 'fundingSource',
      width: 150,
      ifShow: true,
    },
    {
      title: '项目类型',
      dataIndex: 'projectType',
      width: 150,
      ifShow: true,
    },
    {
      title: '总投资',
      dataIndex: 'totalInvestment',
      ifShow: planType === '承建',
      width: 150,
    },
    {
      title: '合同总额',
      dataIndex: 'contractAmount',
      ifShow: planType != '承建',
      width: 150,
    },
    {
      title: '三年滚动投资计划',
      ifShow: true,
      children: [
        {
          title: '合计',
          dataIndex: 'totalAmount',
          width: 150,
        },
        {
          title: parseInt(year),
          dataIndex: 'thisYear',
          width: 150,
        },
        {
          title: parseInt(year) + 1,
          dataIndex: 'secondYear',
          width: 150,
        },
        {
          title: parseInt(year) + 2,
          dataIndex: 'thirdYear',
          width: 150,
        },
      ],
    },
    {
      title: year + '年财政预预算匹配资金',
      dataIndex: 'matchingFunds',
      ifShow: planType === '承建',
      width: 150,
      ifShow: true,
    },
    {
      title: '其中专项债项目' + year + '预计使用专项债资金',
      dataIndex: 'specialBondFunds',
      ifShow: planType === '承建',
      width: 150,
    },
    {
      title: year + '年计划资金',
      dataIndex: 'planFunds',
      width: 150,
      ifShow: true,
    },
    {
      title: '建设性质',
      dataIndex: 'attribute',
      width: 150,
      ifShow: true,
    },
    {
      title: '开工时间',
      dataIndex: 'beginTime',
      width: 150,
      ifShow: true,
    },
    {
      title: '竣工时间',
      dataIndex: 'endTime',
      width: 150,
      ifShow: true,
    },
    {
      title: year + '年底预计形象季度',
      dataIndex: 'schedule',
      width: 150,
      ifShow: true,
    },
    {
      title: '实施主体',
      dataIndex: 'implementingEntity',
      width: 150,
      ifShow: true,
    },
    {
      title: '合同方式',
      dataIndex: 'contract',
      ifShow: planType === '承建',
      width: 150,
    },
    {
      title: '项目主管部门',
      dataIndex: 'competentDepartment',
      ifShow: planType != '承建',
      width: 150,
    },
    {
      title: '实施级别',
      dataIndex: 'implementationLevel',
      width: 150,
      ifShow: true,
    },
    {
      title: '备注',
      dataIndex: 'remarks',
      width: 150,
      ifShow: true,
    },
  ];

  const filterColum = column.filter((item) => item.ifShow);
  return filterColum;
}
